#ifndef DELAY_H
#define DELAY_H

typedef struct time_struct {
    double rise;
    double fall;
} delay_time_t;

typedef enum pin_phase_enum {
    PHASE_NOT_GIVEN, PHASE_INVERTING, PHASE_NONINVERTING, PHASE_NEITHER
} pin_phase_t;

/*
 * The delay_pin_t structure .....
 * Specifies the delay model between a pair of pins
 */
typedef struct delay_pin_struct {
    delay_time_t block;
    delay_time_t drive;
    pin_phase_t phase;
    double load;
    double max_load;
    delay_time_t user_time;
} delay_pin_t;

typedef enum delay_model_enum {
    DELAY_MODEL_UNIT, DELAY_MODEL_LIBRARY, DELAY_MODEL_UNIT_FANOUT,
    DELAY_MODEL_MAPPED
} delay_model_t;

extern int delay_trace();
extern delay_pin_t *get_pin_delay();
extern node_t *delay_latest_output();
extern network_t *delay_generate_decomposition();

extern delay_time_t delay_node_pin();
extern delay_time_t delay_fanout_contribution();
extern delay_time_t delay_required_time();
extern delay_time_t delay_arrival_time();
extern delay_time_t delay_slack_time();
extern double delay_load();
extern double compute_wire_load();

extern int delay_incremental_trace();

typedef enum delay_param_enum {
    DELAY_BLOCK_RISE, DELAY_BLOCK_FALL,
    DELAY_DRIVE_RISE, DELAY_DRIVE_FALL,
    DELAY_PHASE,
    DELAY_OUTPUT_LOAD,
    DELAY_INPUT_LOAD, DELAY_MAX_INPUT_LOAD,
    DELAY_ARRIVAL_RISE, DELAY_ARRIVAL_FALL,
    DELAY_REQUIRED_RISE, DELAY_REQUIRED_FALL,

    DELAY_ADD_WIRE_LOAD, DELAY_WIRE_LOAD_SLOPE,
    DELAY_DEFAULT_DRIVE_RISE, DELAY_DEFAULT_DRIVE_FALL, 
    DELAY_DEFAULT_OUTPUT_LOAD,
    DELAY_DEFAULT_ARRIVAL_RISE, DELAY_DEFAULT_ARRIVAL_FALL, 
    DELAY_DEFAULT_REQUIRED_RISE, DELAY_DEFAULT_REQUIRED_FALL
} delay_param_t;


#define DELAY_NOT_SET -1.0
#define DELAY_VALUE_NOT_GIVEN -1.0
#define DELAY_PHASE_NOT_GIVEN -1

#define DELAY_PHASE_INVERTING 0.0
#define DELAY_PHASE_NONINVERTING 1.0
#define DELAY_PHASE_NEITHER 2.0

extern void delay_set_parameter();
extern double delay_get_parameter();
extern void delay_set_default_parameter();
extern double delay_get_default_parameter();

/* Routines to interface with the mapper */
extern delay_time_t delay_map_simulate();	/* special mapping routine */
extern char **delay_giveaway_pin_delay();	/* library read-in hack */
extern double delay_get_load();
extern delay_time_t delay_get_drive();
extern delay_time_t delay_get_block();

/* Routines to query user-specified data regarding the environment */
extern int delay_get_pi_drive();
extern int delay_get_pi_arrival_time();
extern int delay_get_po_load();
extern int delay_get_po_required_time();

/* io package */
extern void delay_print_blif_wire_loads();

/* networks */
extern void delay_network_alloc();
extern void delay_network_free();
extern void delay_network_dup();

#endif
