 /* file library.h release 1.2 */
 /* last modified: 9/9/90 at 17:32:07 */
#ifndef LIBRARY_H
#define LIBRARY_H


typedef struct library_struct library_t;
struct library_struct {
    lsList classes;		/* list of lib_class_t class descriptions */
    lsList gates;		/* list of lib_gate_t gate descriptions */
    lsList patterns;		/* list of prim_t patterns */
    int nand_flag;
    int add_inverter;
};


typedef struct lib_class_struct lib_class_t;
struct lib_class_struct {
    network_t *network;		/* the logic function for the class */
    lib_class_t *dual_class;	/* pointer to class for complement of fct */
    lsList gates;		/* list of gates in this class */
    library_t *library;		/* pointer back to library */
    char *name;			/* reserved for future use */
};


typedef struct lib_gate_struct lib_gate_t;
struct lib_gate_struct {
    network_t *network;		/* exactly equal to gate->class->network */
    char *name;			/* the gate name */
    char **delay_info;		/* the input pin delays */
    double area;		/* the gate area */
    int symmetric;		/* it is more or less symmetric WRT input pins */
    lib_class_t *class;		/* pointer back to the class */
};


/* normal library functions */
extern library_t *lib_get_library();
extern lsGen lib_gen_classes();
extern lsGen lib_gen_gates();
extern lib_class_t *lib_get_class();
extern char *lib_class_name();
extern network_t *lib_class_network();
extern lib_class_t *lib_class_dual();
extern lib_gate_t *lib_get_gate();
extern char *lib_gate_name();
extern char *lib_gate_pin_name();
extern double lib_gate_area();
extern lib_class_t *lib_gate_class();
extern int lib_gate_num_in();
extern int lib_gate_num_out();

/* for mapped nodes/networks */
extern lib_gate_t *lib_gate_of();
extern int lib_network_is_mapped();
extern int lib_set_gate();

/* obsolete */
extern char *lib_get_gate_name();
extern char *lib_get_pin_name();
extern char *lib_get_out_pin_name();
extern char *lib_get_pin_delay();
extern double lib_get_gate_area();

#endif
