#ifndef NETWORK_H 
#define NETWORK_H


#define lsForeachItem(list, gen, data)				\
    for(gen = lsStart(list); 					\
	(lsNext(gen, (lsGeneric *) &data, LS_NH) == LS_OK) 	\
	    || ((void) lsFinish(gen), 0); )



/*typedef struct network_struct network_t;*/
struct network_struct {
    char *net_name;
    st_table *name_table;
    st_table *short_name_table;
    lsList nodes;		/* list of all nodes */
    lsList pi;			/* list of just primary inputs */
    lsList po;			/* list of just primary outputs */
    network_t *original;	/* UNUSED: pointer to original network */
    double area;		/* HACK: support area keyword */
    int area_given;		/* HACK: support area keyword */
    lsList bdd_list;            /* list of bdd managers */
    network_t *dc_network;      /* external don't care network */
    char *default_delay;	/* Stores default delay info */
};


#define foreach_node(network, gen, p)	\
    lsForeachItem((network)->nodes, gen, p)

#define foreach_primary_input(network, gen, p)	\
    lsForeachItem((network)->pi, gen, p)

#define foreach_primary_output(network, gen, p)	\
    lsForeachItem((network)->po, gen, p)


extern network_t *network_alloc();
extern void network_free();
extern network_t *network_dup();
extern network_t *network_create_from_node();
extern network_t *network_from_nodevec();

extern char *network_name();
extern void network_set_name();
extern int network_num_pi();
extern int network_num_po();
extern int network_num_internal();
extern node_t *network_get_pi();
extern node_t *network_get_po();

extern void network_add_node();
extern void network_add_primary_input();
extern node_t *network_add_primary_output();
extern void network_delete_node();
extern void network_delete_node_gen();
extern node_t *network_find_node();
extern void network_change_node_type();
extern void network_change_node_name();

extern int network_check();
extern int network_is_acyclic();
extern int network_collapse();
extern int network_sweep();
extern int network_cleanup();
extern network_t *network_espresso();

extern array_t *network_dfs();
extern array_t *network_dfs_from_input();
extern array_t *network_tfi();
extern array_t *network_tfo();

extern network_t *network_from_node();

extern void network_initialize();	/* only for I/O routines */
extern int network_append();

extern PLA_t *espresso_read_pla();
extern void discard_pla();
extern PLA_t *network_to_pla();
extern network_t *pla_to_network();
extern network_t *pla_to_network_single();
extern network_t *pla_to_dcnetwork_single();

extern void network_reset_long_name();
extern void network_reset_short_name();
extern void network_swap_names();

extern lsList network_bdd_list();       /*      for BDD package */
extern lsHandle network_add_bdd();      /*      for BDD package */

extern int net_verify();
extern int net_verify_with_dc();
extern network_t *network_dc_network();            /* for don't care network */
extern st_table *attach_dcnetwork_to_network();
extern node_t *find_ex_dc();
extern network_t *or_net_dcnet();

#endif
