.TH MIS 1CAD "14 March 1988"
.SH NAME
misII \- Multiple-level Combinational Logic Optimization Program
.SH SYNOPSIS
.B misII
[options] [file]
.SH DESCRIPTION
\fBMIS\fR is an algorithmic multi-level logic synthesis and
minimization program.  \fBMIS\fR starts from a description
of a combinational logic macro-cell and produces
an optimized set of logic equations which preserves
the input-output behavior of the macro-cell.  The program
includes algorithms for minimizing the area required to
implement the logic equations, and a technology
mapping step to map a network into a user specified cell library.
.PP
\fBMIS\fR can be run in interactive mode accepting commands
from the user, or in batch mode reading commands
from a file or from the command line.
If no options are given on the command line, \fBMIS\fP will
enter interactive mode.
Otherwise, \fBMIS\fP will enter a batch mode.
When running in batch mode, \fBMIS\fP reads its
input from the file given on the command line, or from standard input
if no filename is given;
output is directed to standard output, unless \fB-o\fP is used to
specify an output filename.
.PP
When \fBMIS\fP starts-up, it performs an initial source of the
file ~octtools/lib/misII/lib/.misrc.  Typically this defines a standard
set of aliases for various commands.  The last command in this
file is a 'source ~/.misrc' to allow the user to define his own
aliases at startup.
.SH OPTIONS
.TP 8
.B -c cmdline
Run \fBMIS\fR in batch mode, and execute \fBcmdline\fR.
Multiple commands are separated with semicolons.
.TP 8
.B -f script
Run \fBMIS\fR in the batch mode, and execute commands from the
file \fBscript\fR.
.TP 8
.B -t type
Specifies the type of the input when running in batch mode.
The legal input types are:
Berkeley PLA Format (\fB-t pla\fP),
Berkeley Logic Interchange Format (\fB-t blif\fP),
eqntott(1CAD)-format equation input (\fB-t eqn\fP),
\fIOct Logic View\fR (\fB-t oct\fP),
and suppress input (\fB-t none\fP).
The default input type is \fIblif\fR.
.TP 8
.B -T type
Specifies the type of the output when running in batch mode.
The legal output types are:
Berkeley PLA Format (\fB-T pla\fP),
Berkeley Logic Interchange Format (\fB-T blif\fP),
bdnet(1CAD)-format net-list (\fB-T bdnet\fP),
\fIOct logic view\fR (\fB-T oct\fP),
and suppress output (\fB-T none\fP).
The default output type is \fIblif\fR.
.TP 8
.B -o file
Specifies the output file when running in batch mode.
For \fIOct\fP output, this is a string of the
form \fIcell\fP:\fIview\fP.
The default for the output is the standard output.
.TP 8
.B -s
Suppress sourcing the commands from the standard
startup script (~octtools/lib/misII/lib/.misrc).
.TP 8
.B -x
For batch mode operation, suppress reading an initial network, and
suppress writing an output network.
Equivalent to \fB-t none -T none\fP.
.de XX
.sp 1
.LP
.ti -5
.B
..
.de X1
.br
.ti -5
.B
..
.PP
.SH COMMAND SUMMARY
The commands are summarized below according
to their function (network manipulation,
input-output, network status, command interpreter,
and miscellaneous).
.sp 2
.TS
center;
c s
l l
.
\fBNetwork Manipulation Commands\fP

act_map	do a mapping into "actel" blocks of pld gates
add_inverter	add inverters to the network to make all gates negative
atpg	perform combinational atpg using SAT approach
buffer_opt	inserts buffering trees for high fanout gates
collapse	collapse a network or a set of nodes
cspf_simplify	two-level minimization of each node using CSPF's
decomp	decompose a node into a set of nodes
eliminate	eliminates nodes whose value falls below a threshold
espresso	collapse network and minimize with a two-level minimizer
factor	determine a factored form for a node
gcx	extract common cubes from the network
gkx	extract common multiple-cube divisors from the network
invert	invert a node, and toggle the phase of all of its fanouts
map	technology mapping to find an implementation for the network
phase	phase assignment to minimize number of inverters
resub	perform resubstitution of a node into other nodes in the network
red_removal	perform redundancy removal via atpg
simplify	two-level minimization of each node
speed_up	speed up of nodes in the network
sweep	remove all inverters and buffers from the network
tech_decomp	decompose a network for technology mapping
wd	re-express a node using another node
xl_cover	global cover of nodes by "xilinx" blocks of pld gates	
xl_k_decomp	Karp-Roth decomposition for mapping into "xilinx" gates
xl_merge	merge "xilinx" blocks
xl_partition	local cover of nodes by "xilinx" blocks of pld gates
xl_split	decompose a network (using routing complexity as cost)
.TE
.sp 2
.TS
center;
c s
l l.
\fBInput-Output Commands\fP
read_blif	read a network in BLIF format
read_eqn	read a network in eqntott(1CAD) format
read_oct	read a network from an Oct Logic view
read_pla	read a network in PLA format
read_library	read a library description file
plot	do a plot of the network (only for X11)
set_delay	set delay parameters for primary inputs and outputs 
write_bdnet	write the current (mapped) network in bdnet(1CAD) format
write_blif	write the current network in BLIF format
write_eqn	write the current network in eqntott(1CAD) equation format
write_lif	write the current network in LIF format
write_oct	write the current network into an Oct Logic view
write_pla	write the current network in PLA(5CAD) format
.TE
.sp 1
.TS
center;
c s
l l.
\fBNetwork Status Commands\fP
constraints	print the delay constraints for a set of nodes
print	print logic function associated with a node
print_altname	print the short (and long) names for anode
print_delay	timing simulate a network and print results
print_factor	print the factored form associated with a node
print_gate	print the library information associated with a gate
print_io	print the fanin and fanout of a node (or the network)
print_kernel	print the kernels (and subkernels) of a set of functions
print_level	print the levels of a set of nodes
print_library	list the gates in the current library
print_stats	print statistics on a set of nodes
print_value	print the value of a set of nodes
.TE
.sp 1
.TS
center;
c s
l l.
\fBCommand Interpreter\fP
alias	provide an alias for a command
chng_name	switch between short and long forms for node names
echo	merely echo the arguments
fanout_alg	select a fanout optimization algorithm (to be used by map)
fanout_param	set some parameters for fanput algorithm (to be used by map)
help	provide on-line information on commands
quit	exit MIS
reset_name	rename all of the short names in the network
save	save a copy of the current executable
set	set an environment variable
source	execute commands from a file
time	provide a simple elapsed time value
unalias	remove the definition of an alias
undo	undo the result of the last command which changed the network
unset	unset an environment variable
usage	provide a dump of process statistics
.TE
.sp 1
.TS
center;
c s
l l.
\fBMiscellaneous\fP
bdsyn	special command used by bdsyn(1CAD)
simulate	logic simulation of the current network
sim_verify	verify networks equivalent via simulation
verify	verify equivalence of two networks
.TE
.sp .5i
.SH NODELIST ARGUMENTS
Most commands which take a node also take a list of nodes as an
argument.  This is referred to as a \fBnode-list\fP in the
documentation below.
This list of nodes includes \fB*\fP to specify
all nodes in the network, \fBi()\fP to specify the primary
inputs of the network, \fBo()\fP to specify the primary
outputs of the network, \fBi(node)\fP to specify the
direct fanin of \fInode\fP, and \fBo(node)\fP to specify the
direct fanout of \fInode\fP.
.sp .5i
.SH STANDARD ALIASES
When \fBMIS\fP starts, it executes commands from a system startup file
(usually ~octtools/lib/misII/lib/.misrc).  This defines a standard set of
aliases, and then sources the file ~/.misrc to allow
users to define their own set of aliases.  The default alias set includes
the following aliases which have proven useful.  Note that many of the aliases
are intended for compatibility with \fBMIS\fP Version #1.3.
.TS
center;
c s s
c c c
l l l.
Standard Aliases
alias	command	description
ai	add_inverter	add inverters to a network to correct the phases
alt	print_altname	print both long and short names for a node
asb	resub -a	algebraic resubstitution
c	chng_name	toggle between long and short names
clp	collapse	collapse network
el	eliminate	eliminate nodes below a threshold
exit	quit	terminate program
gd	decomp -g	good decomposition (i.e., best kernel decomposition)
gf	factor -g	good factoring (i.e., best kernel factoring)
gp	phase -g	good phase assignment (i.e., more expensive)
inv	invert	invert a node keeping network function consistent
nts	print_stats	print network status (including factored form)
p	print	print sum-of-products form of a node
pat	print_delay -a	print node arrival times
pd	print_delay	print delay
pf	print_factor	print factored form of a node
pg	print_gate	print gate information for a node
pgc	print_gate -s	summarize gate information for the network
pio	print_io	print inputs and outputs of a node or the network
pk	print_kernel	print kernels of a node
plt	print_delay -l	print output loading for each node
pn	p -n	print nodes in 'negative' form
prt	print_delay -r	print node required times
ps	print_stats -f	print network status (including factored form)
psf	print_stats	print network status
pst	print_delay -s	print node slack times
pv	print_value	print node values
qd	decomp -q	quick decomposition (i.e., any kernel decomposition)
qf	factor -g	quick factoring (i.e., any kernel factoring)
qp	phase -q	quick phase (i.e., simple greedy algorithm)
re	read_eqn	read equations from a file
rl	read_blif	read blif network from a file
rlib	read_library	read library in genlib format
ro	read_oct	read network from an Oct view
rp	read_pla	read PLA in espresso format
rsn	reset_name	reset all short names starting from 'a'
sim	simulate	logic simulation on a network
sim0	simplify -d	quick minimization of a node (no don't cares)
sim1	simplify -m nocomp -d	complete minimization of a node (no don't cares)
sim2	simplify	single pass minimization with fanin DC-set
sim3	simplify -m nocomp	complete minimization with fanin DC-set
so 	source	source a script file
sw	sweep	remove buffers, inverters from a network
td	tech_decomp	decompose network to meet AND/OR constraints
u	undo	undo last command which changed network
wb	write_bdnet	write mapped network in BDNET format
wl	write_blif	write network in blif format
wp	write_pla	write network in Espresso PLA format
wo	write_oct	write network as an Oct view
.TE
.bp
.SH DETAILED COMMAND DESCRIPTIONS
.PP
.so add_inverter.1
.so alias.1
.so atpg.1
.so bdsyn.1
.so chng_name.1
.so collapse.1
.so constraints.1
.so cspf_simplify.1
.so decomp.1
.so echo.1
.so eliminate.1
.so espresso.1
.so factor.1
.so fanout_alg.1
.so fanout_param.1
.so gcx.1
.so gkx.1
.so help.1
.so invert.1
.so map.1
.so phase.1
.so plot.1
.so print.1
.so print_altname.1
.so print_delay.1
.so print_factor.1
.so print_gate.1
.so print_io.1
.so print_kernel.1
.so print_level.1
.so print_library.1
.so print_stats.1
.so print_value.1
.so quit.1
.so read_blif.1
.so read_eqn.1
.so read_oct.1
.so read_pla.1
.so read_library.1
.so red_removal.1
.so reset_name.1
.so resub.1
.so save.1
.so set.1
.so set_delay.1
.so simplify.1
.so simulate.1
.so sim_verify.1
.so source.1
.so speed_up.1
.so sweep.1
.so tech_decomp.1
.so time.1
.so unalias.1
.so undo.1
.so unset.1
.so usage.1
.so verify.1
.so wd.1
.so write_bdnet.1
.so write_blif.1
.so write_eqn.1
.so write_lif.1
.so write_oct.1
.so write_pla.1
.so xl_cover.1
.so xl_k_decomp.1
.so xl_merge.1
.so xl_partition.1
.so xl_split.1
.SH FILES
$OCTTOOLS/lib/misII/ex
.br
$OCTTOOLS/lib/misII/lib/.misrc
.br
$OCTTOOLS/lib/misII/lib/script
.br
$OCTTOOLS/lib/misII/lib/*
.SH "SEE ALSO"
espresso(1CAD), espresso(5CAD), eqntott(1CAD), $OCTTOOLS/doc/blif.doc.
.SH AUTHOR
Richard Rudell
.br
Albert Wang
.br
Rick Spickelmier (Oct read and write)
